@@ -34,7 +34,7 @@ Usage::
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -77,22 +77,22 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeDirectoriesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedirectoriespaginator)
     """
 
     def paginate(
-        self, *, DirectoryIds: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, DirectoryIds: Sequence[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeDirectoriesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeDirectories.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedirectoriespaginator)
         """
 
 
 class DescribeDomainControllersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedomaincontrollerspaginator)
     """
 
@@ -100,18 +100,18 @@ class DescribeDomainControllersPaginator(Boto3Paginator):
         self,
         *,
         DirectoryId: str,
-        DomainControllerIds: List[str] = None,
+        DomainControllerIds: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeDomainControllersResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeDomainControllers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describedomaincontrollerspaginator)
         """
 
 
 class DescribeSharedDirectoriesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describeshareddirectoriespaginator)
     """
 
@@ -119,18 +119,18 @@ class DescribeSharedDirectoriesPaginator(Boto3Paginator):
         self,
         *,
         OwnerDirectoryId: str,
-        SharedDirectoryIds: List[str] = None,
+        SharedDirectoryIds: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeSharedDirectoriesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeSharedDirectories.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describeshareddirectoriespaginator)
         """
 
 
 class DescribeSnapshotsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describesnapshotspaginator)
     """
 
@@ -138,18 +138,18 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
         self,
         *,
         DirectoryId: str = None,
-        SnapshotIds: List[str] = None,
+        SnapshotIds: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeSnapshotsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeSnapshots.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describesnapshotspaginator)
         """
 
 
 class DescribeTrustsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describetrustspaginator)
     """
 
@@ -157,18 +157,18 @@ class DescribeTrustsPaginator(Boto3Paginator):
         self,
         *,
         DirectoryId: str = None,
-        TrustIds: List[str] = None,
+        TrustIds: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeTrustsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.DescribeTrusts.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#describetrustspaginator)
         """
 
 
 class ListIpRoutesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listiproutespaginator)
     """
 
@@ -176,14 +176,14 @@ class ListIpRoutesPaginator(Boto3Paginator):
         self, *, DirectoryId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListIpRoutesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListIpRoutes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listiproutespaginator)
         """
 
 
 class ListLogSubscriptionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listlogsubscriptionspaginator)
     """
 
@@ -191,14 +191,14 @@ class ListLogSubscriptionsPaginator(Boto3Paginator):
         self, *, DirectoryId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListLogSubscriptionsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListLogSubscriptions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listlogsubscriptionspaginator)
         """
 
 
 class ListSchemaExtensionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listschemaextensionspaginator)
     """
 
@@ -206,14 +206,14 @@ class ListSchemaExtensionsPaginator(Boto3Paginator):
         self, *, DirectoryId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListSchemaExtensionsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListSchemaExtensions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listschemaextensionspaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listtagsforresourcepaginator)
     """
 
@@ -221,6 +221,6 @@ class ListTagsForResourcePaginator(Boto3Paginator):
         self, *, ResourceId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListTagsForResourceResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/ds.html#DirectoryService.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ds/paginators.html#listtagsforresourcepaginator)
         """
